==> istio-model-v1alpha3-6.8.1-sources.jar: io/fabric8/istio/api/internal/protobuf/types/ValueListValueFluent.java <==
package io.fabric8.istio.api.internal.protobuf.types;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.Object;
import java.lang.String;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class ValueListValueFluent<A extends ValueListValueFluent<A>> extends BaseFluent<A>{
  public ValueListValueFluent() {
  }
  public ValueListValueFluent(ValueListValue instance) {
    instance = (instance != null ? instance : new ValueListValue());

    if (instance != null) {
      this.withListValue(instance.getListValue());
      this.withListValue(instance.getListValue());
    }
  }
  private ListValueBuilder listValue;
  public ListValue buildListValue() {
    return this.listValue!=null ?this.listValue.build():null;
  }
  public A withListValue(ListValue listValue) {
    _visitables.get("listValue").remove(this.listValue);
    if (listValue!=null){ this.listValue= new ListValueBuilder(listValue); _visitables.get("listValue").add(this.listValue);} else { this.listValue = null; _visitables.get("listValue").remove(this.listValue); } return (A) this;
  }
  public boolean hasListValue() {
    return this.listValue != null;
  }
  public ListValueNested<A> withNewListValue() {
    return new ListValueNested(null);
  }
  public ListValueNested<A> withNewListValueLike(ListValue item) {
    return new ListValueNested(item);
  }
  public ListValueNested<A> editListValue() {
    return withNewListValueLike(java.util.Optional.ofNullable(buildListValue()).orElse(null));
  }
  public ListValueNested<A> editOrNewListValue() {
    return withNewListValueLike(java.util.Optional.ofNullable(buildListValue()).orElse(new ListValueBuilder().build()));
  }
  public ListValueNested<A> editOrNewListValueLike(ListValue item) {
    return withNewListValueLike(java.util.Optional.ofNullable(buildListValue()).orElse(item));
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ValueListValueFluent that = (ValueListValueFluent) o;
    if (!java.util.Objects.equals(listValue, that.listValue)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(listValue,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (listValue != null) { sb.append("listValue:"); sb.append(listValue); }
    sb.append("}");
    return sb.toString();
  }
  public class ListValueNested<N> extends ListValueFluent<ListValueNested<N>> implements Nested<N>{
    ListValueNested(ListValue item) {
      this.builder = new ListValueBuilder(this, item);
    }
    ListValueBuilder builder;
    public N and() {
      return (N) ValueListValueFluent.this.withListValue(builder.build());
    }
    public N endListValue() {
      return and();
    }
    
  }
  
}

==> istio-model-v1alpha3-6.9.0-sources.jar: io/fabric8/istio/api/internal/protobuf/types/ValueListValueFluent.java <==
package io.fabric8.istio.api.internal.protobuf.types;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.Object;
import java.lang.String;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class ValueListValueFluent<A extends ValueListValueFluent<A>> extends BaseFluent<A>{
  public ValueListValueFluent() {
  }
  
  public ValueListValueFluent(ValueListValue instance) {
    this.copyInstance(instance);
  }
  private ListValueBuilder listValue;
  
  protected void copyInstance(ValueListValue instance) {
    instance = (instance != null ? instance : new ValueListValue());
  
    if (instance != null) {
        this.withListValue(instance.getListValue());
        this.withListValue(instance.getListValue());
      }
  }
  
  public ListValue buildListValue() {
    return this.listValue!=null ?this.listValue.build():null;
  }
  
  public A withListValue(ListValue listValue) {
    _visitables.get("listValue").remove(this.listValue);
    if (listValue!=null){ this.listValue= new ListValueBuilder(listValue); _visitables.get("listValue").add(this.listValue);} else { this.listValue = null; _visitables.get("listValue").remove(this.listValue); } return (A) this;
  }
  
  public boolean hasListValue() {
    return this.listValue != null;
  }
  
  public ListValueNested<A> withNewListValue() {
    return new ListValueNested(null);
  }
  
  public ListValueNested<A> withNewListValueLike(ListValue item) {
    return new ListValueNested(item);
  }
  
  public ListValueNested<A> editListValue() {
    return withNewListValueLike(java.util.Optional.ofNullable(buildListValue()).orElse(null));
  }
  
  public ListValueNested<A> editOrNewListValue() {
    return withNewListValueLike(java.util.Optional.ofNullable(buildListValue()).orElse(new ListValueBuilder().build()));
  }
  
  public ListValueNested<A> editOrNewListValueLike(ListValue item) {
    return withNewListValueLike(java.util.Optional.ofNullable(buildListValue()).orElse(item));
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ValueListValueFluent that = (ValueListValueFluent) o;
    if (!java.util.Objects.equals(listValue, that.listValue)) return false;
  
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(listValue,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (listValue != null) { sb.append("listValue:"); sb.append(listValue); }
    sb.append("}");
    return sb.toString();
  }
  public class ListValueNested<N> extends ListValueFluent<ListValueNested<N>> implements Nested<N>{
    ListValueNested(ListValue item) {
      this.builder = new ListValueBuilder(this, item);
    }
    ListValueBuilder builder;
    
    public N and() {
      return (N) ValueListValueFluent.this.withListValue(builder.build());
    }
    
    public N endListValue() {
      return and();
    }
    
  
  }

}
